@@ -381,21 +381,22 @@ def ensure_pvc(
     # So we run "get" first, to allow run for existing bound pvc
     # On k8s 1.21 it will error out otherwise, on later versions "wait" works
     pvc_status: str = kubectl.run('get persistentvolumeclaim --output', pvc_phase_jsonpath, pvc_name).stdout
-    if pvc_status.lower() not in pvc_desired_states:
-        desired_states = ' '.join(pvc_desired_states)
-        logger.warning(f'{pvc_status=} {desired_states=}\nAwaiting state change')
+    if pvc_status in pvc_desired_states:
+        return
+    desired_states = ' '.join(pvc_desired_states)
+    logger.warning(f'{pvc_status=} {desired_states=}\nAwaiting state change')
 
-        kubectl.set_args('wait persistentvolumeclaim', pvc_name, '--timeout=15s')
-        for phase in pvc_desired_states + pvc_desired_states:  # checking every phase twice to avoid change drift
-            out = kubectl.run(f'--for={pvc_phase_jsonpath}={phase}', show_cmd_level='warning')
-            if not out.returncode:
-                logger.info(f'persistentvolumeclaim {pvc_name} is in desired state: {phase}')
-                return
-        kubectl.set_args('')
-        pvc_status = kubectl.run('get persistentvolumeclaim --output', pvc_phase_jsonpath, pvc_name).stdout
-        error_msg = f'{pvc_name=} {pvc_status=} Desired states: {" ".join(pvc_desired_states)}'
-        logger.error(error_msg)
-        raise RuntimeError(error_msg)
+    kubectl.set_args('wait persistentvolumeclaim', pvc_name, '--timeout=15s')
+    for phase in pvc_desired_states + pvc_desired_states:  # checking every phase twice to avoid change drift
+        out = kubectl.run(f'--for={pvc_phase_jsonpath}={phase}', show_cmd_level='warning')
+        if not out.returncode:
+            logger.info(f'persistentvolumeclaim {pvc_name} is in desired state: {phase}')
+            return
+    kubectl.set_args('')
+    pvc_status = kubectl.run('get persistentvolumeclaim --output', pvc_phase_jsonpath, pvc_name).stdout
+    error_msg = f'{pvc_name=} {pvc_status=} Desired states: {" ".join(pvc_desired_states)}'
+    logger.error(error_msg)
+    raise RuntimeError(error_msg)
 
 
 def ensure_daemonset(spec: dict, logger: logging.Logger) -> None:
@@ -538,7 +539,7 @@ def await_k8s_job_completion(spec: dict, tail: Optional[int] = None) -> bool:
         response = kubectl_run(job_status_cmd)
 
     get_pods_cmd = f'get pods --ignore-not-found --selector=job-name={name}'
-    kubectl.stream(
+    kubectl.stream( # todo: at this stage, imageID could still be blank. Move this downstream to improve chances.
         get_pods_cmd,
         r"""--output jsonpath='{range .items[*].status.containerStatuses[*]}{.image} -> {.imageID}{"\n"}{end}'""",
         show_cmd=False,
@@ -896,3 +897,24 @@ def set_image_pull_policy_default(spec: dict, refresh_rate_default: float):
         return
 
     time.sleep(sleep)
+
+
+def get_size_on_remote(spec, path) -> str:
+    """Calculate the size of a file/dir on a remote fs
+
+    :param spec: spec dict
+    :param path: the remote path to measure
+    :return: du -sh size result or empty string
+    """
+    if spec['DISK_TOTALS'] not in ['yes', 'remote']:
+        return ''
+    logger = log.get_logger('plain')
+    kubectl = Executable('kubectl', f'kubectl --namespace', spec['NAMESPACE'], logger=logger)
+    name = create_oneliner_job(spec, command='du -sh {}'.format(path), container_name='du', await_completion=True)
+
+    resp = kubectl.run(f'logs --ignore-errors --selector=job-{name=}', check=False)
+    logger.error(resp.stderr)
+    logger.info(resp.stdout)
+    if size := next((x.strip() for x in resp.stdout.strip().splitlines() if x), ''):
+        return size.split()[0]
+    return ''
